@@ -6,18 +6,15 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QLKEY_H
 #define QLKEY_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include <qnamespace.h>
-#include "LString.h"
+#include <string>
+
 
 /**
  * Return true if the key event is a modifier.
@@ -43,7 +40,7 @@ bool q_is_modifier(int qkey)
  * Return the numeric Qt Key corresponding to the
  * given symbol name.
  */
-int string_to_qkey(string const & str)
+int string_to_qkey(std::string const & str)
 {
 	// FIX! (Lgb)
 
@@ -346,7 +343,7 @@ int string_to_qkey(string const & str)
  * Convert the Qt keypress into a string understandable
  * by the LyX core (same as XKeysymToString).
  */
-string const qkey_to_string(int lkey)
+std::string const qkey_to_string(int lkey)
 {
 	switch (lkey) {
 	case Qt::Key_Escape: return "Escape";
